@@ -8,12 +8,16 @@ from .configfile import (
     PrometheusConfigFileOptions,
     PrometheusConfigFile,
 )
+from .configfileext import (
+    PrometheusConfigFileExt_Kubernetes,
+)
 
-__version__ = "0.7.5"
+__version__ = "0.7.6"
 
 __all__ = [
     'PrometheusBuilder',
     'PrometheusOptions',
     'PrometheusConfigFileOptions',
     'PrometheusConfigFile',
+    'PrometheusConfigFileExt_Kubernetes',
 ]
